@@ -46,7 +46,7 @@ def bind(blueprint, methods, tenant=None):
 
                 allowed_methods = item[1]
                 blueprint.add_url_rule(new_rule, endpoint.__name__, view_function, methods=allowed_methods)
-                blueprint.add_url_rule(new_rule_with_slash, endpoint.__name__, view_function, methods=allowed_methods)
+                blueprint.add_url_rule(new_rule_with_slash, f'{endpoint.__name__}_slash', view_function, methods=allowed_methods)
     return blueprint
 
 
@@ -76,10 +76,11 @@ class RouteBuilder(Blueprint):
         self.url_prefix = f'/{url}'
         self.key = model.__mapper__.primary_key[0].name
 
-        if 'key' in kwargs.keys():
-            self.key = getattr(self.model, kwargs.get('key'))
+        if kwargs.get('lookup', None):
+            key = model.__mapper__.primary_key[0].name
+            self.key = getattr(self.model, kwargs.get('lookup'))
         self.delete_flag = False
-        self.bind(getattr(self, 'methods', None) or DEFAULT_METHODS)
+        # self.bind(getattr(self, 'methods', None) or DEFAULT_METHODS)
 
     def _before_request(self):
         self.querystring()
